==> kubernetes-client-4.11.0-sources.jar: io/fabric8/kubernetes/client/dsl/internal/rbac/v1/RoleBindingOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.rbac.v1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.rbac.DoneableRoleBinding;
import io.fabric8.kubernetes.api.model.rbac.RoleBinding;
import io.fabric8.kubernetes.api.model.rbac.RoleBindingList;
import io.fabric8.kubernetes.api.model.rbac.DoneableRoleBinding;

import java.util.Map;
import java.util.TreeMap;


public class RoleBindingOperationsImpl extends HasMetadataOperation<RoleBinding, RoleBindingList, DoneableRoleBinding, Resource<RoleBinding, DoneableRoleBinding>> {

  public RoleBindingOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public RoleBindingOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public RoleBindingOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("rbac.authorization.k8s.io")
    .withApiGroupVersion("v1")
    .withPlural("rolebindings"));
    this.type = RoleBinding.class;
    this.listType = RoleBindingList.class;
    this.doneableType = DoneableRoleBinding.class;
  }

  public RoleBindingOperationsImpl newInstance(OperationContext context) {
    return new RoleBindingOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-5.3.0-sources.jar: io/fabric8/kubernetes/client/dsl/internal/rbac/v1/RoleBindingOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.rbac.v1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.rbac.RoleBinding;
import io.fabric8.kubernetes.api.model.rbac.RoleBindingBuilder;
import io.fabric8.kubernetes.api.model.rbac.RoleBindingList;

import java.util.Map;
import java.util.TreeMap;


public class RoleBindingOperationsImpl extends HasMetadataOperation<RoleBinding, RoleBindingList, Resource<RoleBinding>> {

  public RoleBindingOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public RoleBindingOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public RoleBindingOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("rbac.authorization.k8s.io")
    .withApiGroupVersion("v1")
    .withPlural("rolebindings"));
    this.type = RoleBinding.class;
    this.listType = RoleBindingList.class;
  }

  public RoleBindingOperationsImpl newInstance(OperationContext context) {
    return new RoleBindingOperationsImpl(context);
  }

  @Override
  public RoleBinding edit(Visitor... visitors) {
    return patch(new RoleBindingBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
